:orphan:

.. this page is referenced from the topbar which comes from the theme

Community
=========

Dask is used and developed by individuals at a variety of institutions.  It
sits within the broader Python numeric ecosystem commonly referred to as PyData
or SciPy.

Community Meeting
-----------------

.. note::

    We've combined the monthly Dask Demo Day and Dask Developer Meeting into a single, monthly Dask community meeting.

Join us for the monthly community meetings on the first Thursday of the month at
10:00 US Central Time. `Join via Zoom <https://dask.org/meeting-room>`__.

Have something you'd like to share? Let us know by dropping a comment on `this GitHub issue <https://github.com/dask/community/issues/307>`__.

Meeting notes are available in
`this Google doc <https://docs.google.com/document/d/1UqNAP87a56ERH_xkQsS5Q_0PKYybd5Lj2WANy_hRzI0/edit>`_.

.. raw:: html

    <iframe id="calendariframe" src="https://calendar.google.com/calendar/embed?ctz=local&amp;src=4l0vts0c1cgdbq5jhcogj55sfs%40group.calendar.google.com" style="border: 0" width="800" height="600" frameborder="0" scrolling="no"></iframe>
    <script>document.getElementById("calendariframe").src = document.getElementById("calendariframe").src.replace("ctz=local", "ctz=" + Intl.DateTimeFormat().resolvedOptions().timeZone)</script>

You can subscribe to this calendar to be notified of changes:

* `Google Calendar <https://calendar.google.com/calendar/u/0?cid=NGwwdnRzMGMxY2dkYnE1amhjb2dqNTVzZnNAZ3JvdXAuY2FsZW5kYXIuZ29vZ2xlLmNvbQ>`__
* `iCal <https://calendar.google.com/calendar/ical/4l0vts0c1cgdbq5jhcogj55sfs%40group.calendar.google.com/public/basic.ics>`__

Discussion
----------

Conversation happens in the following places:

#.  **Usage questions, requests for help, and general discussions** happen in the
    `Dask Discourse forum`_. If your discussion topic is not a bug report
    or a feature request, this is the best place to start. It's also a good
    place to show off cool things you have built using Dask and to get to know other
    community members.
#.  **Usage questions** may also be directed to `Stack Overflow with the #dask tag`_,
    which is monitored by Dask developers. However, the scope of what is considered
    a good Stack Overflow question can be narrow, so the Dask Discourse forum may
    be a better place to start.
#.  **Bug reports and feature requests** are managed on the `GitHub issue
    tracker`_
#.  **Real-time chat** occurs on
    `https://dask.slack.com/ <https://join.slack.com/t/dask/shared_invite/zt-mfmh7quc-nIrXL6ocgiUH2haLYA914g>`_.
    Note that Slack chat not easily searchable and indexed by search engines, so
    detailed discussion topics around bug reports or usage should go to GitHub issues or
    the Dask Discourse forum, respectively.

.. _`Dask Discourse forum`: https://dask.discourse.group
.. _`Stack Overflow with the #dask tag`: https://stackoverflow.com/questions/tagged/dask
.. _`GitHub issue tracker`: https://github.com/dask/dask/issues/


Asking for help
---------------

We welcome usage questions and bug reports from all users, even those who are
new to using the project.  There are a few things you can do to improve the
likelihood of quickly getting a good answer.

1.  **Ask questions in the right place**:  We strongly prefer the use
    of `Dask Discourse forum`_ or `GitHub issues <https://github.com/dask/dask/issues/>`_ over Slack chat.  Discourse and
    GitHub are more easily searchable by future users, and therefore can be
    useful to many more people than those directly involved.

    If you have a general question about how something should work or
    want best practices then use Discourse.  If you think you have found a
    bug then use GitHub

2.  **Ask only in one place**: Please restrict yourself to posting your
    question in only one place (likely the Dask Discourse or GitHub) and don't post
    in both

3.  **Create a minimal example**:  It is ideal to create `minimal, complete,
    verifiable examples <https://stackoverflow.com/help/mcve>`_.  This
    significantly reduces the time that answerers spend understanding your
    situation, resulting in higher quality answers more quickly.

    See also `this blogpost
    <http://matthewrocklin.com/blog/work/2018/02/28/minimal-bug-reports>`_
    about crafting minimal bug reports.  These have a much higher likelihood of
    being answered


Paid support
------------
In addition to the previous options, paid support is available from the
following organizations (listed in alphabetical order):

-   `Anaconda <https://www.anaconda.com/products/professional-services>`_
-  `Coiled <https://coiled.io?utm_source=dask-docs&utm_medium=support>`_
-   `Quansight <https://www.quansight.com/>`_
